Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(216)

Unified Diff: client/site_tests/power_Backlight/power_Backlight.py

Issue 2110005: Also stop powerd in power_Backlight and power_LoadTest (Closed) Base URL: ssh://git@chromiumos-git/autotest.git
Patch Set: Address review comments Created 10 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | client/site_tests/power_LoadTest/power_LoadTest.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: client/site_tests/power_Backlight/power_Backlight.py
diff --git a/client/site_tests/power_Backlight/power_Backlight.py b/client/site_tests/power_Backlight/power_Backlight.py
index c031e50b60fcabf014049c977e435b8fac5b09e6..8157a12f36e22f65ea235a04e0af225c94094be2 100644
--- a/client/site_tests/power_Backlight/power_Backlight.py
+++ b/client/site_tests/power_Backlight/power_Backlight.py
@@ -12,8 +12,9 @@ class power_Backlight(test.test):
def run_once(self, delay=60, seconds=10, tries=20):
# disable screen locker
os.system('stop screen-locker')
+ os.system('stop powerd')
# disable screen blanking. Stopping screen-locker isn't
# synchronous :(. Add a sleep for now, till powerd comes around
@@ -56,6 +57,7 @@ class power_Backlight(test.test):
def cleanup(self):
- # Re-enable screen locker. This also re-enables dpms.
- utils.system('start screen-locker')
+ # Re-enable screen locker and powerd. This also re-enables dpms.
+ os.system('start powerd')
+ os.system('start screen-locker')
« no previous file with comments | « no previous file | client/site_tests/power_LoadTest/power_LoadTest.py » ('j') | no next file with comments »

Powered by Google App Engine
@@ -12,8 +12,9 @@ class power_Backlight(test.test):
def run_once(self, delay=60, seconds=10, tries=20):
- # disable screen locker
+ # disable screen locker and powerd
os.system('stop screen-locker')
This is Rietveld 408576698